@@ -1,8 +1,7 @@
-from metagraph import translator, dtypes
+from metagraph import translator
 from metagraph.plugins import has_grblas
-from .types import PythonNodeMapType, PythonNodeSetType, dtype_casting
+from .types import PythonNodeMapType, PythonNodeSetType
 from ..numpy.types import NumpyNodeMap, NumpyNodeSet
-import numpy as np
 
 
 @translator
@@ -12,18 +11,17 @@ def nodemap_to_nodeset(x: PythonNodeMapType, **props) -> PythonNodeSetType:
 
 @translator
 def nodeset_from_numpy(x: NumpyNodeSet, **props) -> PythonNodeSetType:
-    return set(x.value)
+    return set(x.value.tolist())
 
 
 @translator
 def nodemap_from_numpy(x: NumpyNodeMap, **props) -> PythonNodeMapType:
-    cast = dtype_casting[dtypes.dtypes_simplified[x.value.dtype]]
-    return {nid: cast(val) for nid, val in zip(x.nodes, x.value)}
+    return dict(zip(x.nodes.tolist(), x.value.tolist()))
 
 
 @translator
 def nodeset_from_numpy_nodemap(x: NumpyNodeMap, **props) -> PythonNodeSetType:
-    return set(x.nodes)
+    return set(x.nodes.tolist())
 
 
 if has_grblas:
@@ -32,5 +30,4 @@ if has_grblas:
     @translator
     def nodemap_from_graphblas(x: GrblasNodeMap, **props) -> PythonNodeMapType:
         idx, vals = x.value.to_values()
-        data = dict(zip(idx, vals))
-        return data
+        return dict(zip(idx.tolist(), vals.tolist()))
