@@ -3,6 +3,7 @@ import pytest
 import networkx as nx
 import numpy as np
 import math
+from collections import defaultdict
 
 from . import MultiVerify
 
@@ -146,7 +147,7 @@ def test_graphwave(default_plugin_resolver):
         matrix, node_map = matrix_node_map_pair
 
         class_to_vectors = {c: [] for c in classes}
-        for node_id in node_map.pos2id:
+        for node_id in node_map.nodes:
             c = node_to_class[node_id]
             class_to_vectors[c].append(matrix[node_id])
 
@@ -228,7 +229,7 @@ def test_hope_katz(default_plugin_resolver):
     nx_graph.add_edge(b_end_node + number_of_bridging_nodes, center_node_id)
 
     # Verify Results
-
+    nx.set_edge_attributes(nx_graph, 1, "weight")
     graph = dpr.wrappers.Graph.NetworkXGraph(nx_graph)
     embedding_size = 24
     beta = 0.1
@@ -338,6 +339,7 @@ The test verifies for the testing graph that the 20 nearest neighbors in the emb
     nx_graph.add_edge(9999_29_00, 29)
     nx_graph.add_edge(9999_29_00, 0)
 
+    nx.set_edge_attributes(nx_graph, 1, "weight")
     graph = dpr.wrappers.Graph.NetworkXGraph(nx_graph)
 
     mv = MultiVerify(dpr)
@@ -345,22 +347,22 @@ The test verifies for the testing graph that the 20 nearest neighbors in the emb
     embedding_size = 50
     node_feature_nodes = dpr.wrappers.NodeMap.NumpyNodeMap(
         np.arange(33),
-        node_ids=np.concatenate(
+        nodes=np.concatenate(
             [np.arange(30), np.array([9999_09_10, 9999_19_20, 9999_29_00])]
         ),
     )
+
     node_feature_np_matrix = np.zeros([33, embedding_size])
     node_feature_np_matrix[a_nodes, 0] = 1
     node_feature_np_matrix[b_nodes, 1] = 1
     node_feature_np_matrix[c_nodes, 2] = 1
     node_feature_np_matrix[30:] = np.ones(embedding_size)
-    node_feature_matrix = dpr.wrappers.Matrix.NumpyMatrix(node_feature_np_matrix)
 
     # Run GraphSAGE
     walk_length = 5
     walks_per_node = 1
-    layer_sizes = dpr.wrappers.Vector.NumpyVector(np.array([40, 30]))
-    samples_per_layer = dpr.wrappers.Vector.NumpyVector(np.array([10, 5]))
+    layer_sizes = np.array([40, 30])
+    samples_per_layer = np.array([10, 5])
     epochs = 35
     learning_rate = 5e-3
     batch_size = 2
@@ -370,7 +372,7 @@ The test verifies for the testing graph that the 20 nearest neighbors in the emb
     embedding = mv.compute(
         "embedding.train.graph_sage.mean",
         graph,
-        node_feature_matrix,
+        node_feature_np_matrix,
         node_feature_nodes,
         walk_length,
         walks_per_node,
@@ -392,21 +394,17 @@ The test verifies for the testing graph that the 20 nearest neighbors in the emb
     unseen_node_feature_np_matrix = np.zeros([51, embedding_size])
     unseen_node_feature_np_matrix[0:20, 0] = 1
     unseen_node_feature_np_matrix[20:50, 1] = 1
-    unseen_node_feature_matrix = dpr.wrappers.Matrix.NumpyMatrix(
-        unseen_node_feature_np_matrix
-    )
+
     unseen_node_feature_nodes = dpr.wrappers.NodeMap.NumpyNodeMap(
         np.arange(51),
-        node_ids=np.concatenate(
-            [unseen_a_nodes, unseen_b_nodes, np.array([8888_00_20])]
-        ),
+        nodes=np.concatenate([unseen_a_nodes, unseen_b_nodes, np.array([8888_00_20])]),
     )
     unseen_graph = dpr.wrappers.Graph.NetworkXGraph(unseen_nx_graph)
     matrix = mv.transform(
-        dpr.plugins.metagraph_stellargraph.algos.util.graph_sage_node_embedding.apply,
+        dpr.plugins.metagraph_stellargraph.algos.embedding.apply.graph_sage,
         embedding,
         unseen_graph,
-        unseen_node_feature_matrix,
+        unseen_node_feature_np_matrix,
         unseen_node_feature_nodes,
         batch_size=batch_size,
         worker_count=1,
@@ -489,13 +487,14 @@ def test_line(default_plugin_resolver):
         b_labels = predicted_labels[b_indices]
         c_labels = predicted_labels[c_indices]
 
-        assert len(np.unique(a_labels)) == 1
-        assert len(np.unique(b_labels)) == 1
-        assert len(np.unique(c_labels)) == 1
+        a_label = int(np.median(a_labels))
+        b_label = int(np.median(b_labels))
+        c_label = int(np.median(c_labels))
+
+        assert np.sum(a_labels == a_label) / len(a_labels) > 0.95
+        assert np.sum(b_labels == b_label) / len(b_labels) > 0.95
+        assert np.sum(c_labels == c_label) / len(c_labels) > 0.95
 
-        a_label = a_labels[0]
-        b_label = b_labels[0]
-        c_label = c_labels[0]
         a_variances = np.sum(gmm.covariances_[a_label] * np.eye(embedding_size), axis=0)
         b_variances = np.sum(gmm.covariances_[b_label] * np.eye(embedding_size), axis=0)
         c_variances = np.sum(gmm.covariances_[c_label] * np.eye(embedding_size), axis=0)
@@ -526,3 +525,24 @@ def test_line(default_plugin_resolver):
     ).custom_compare(
         cmp_func
     )
+
+
+def test_apply_node_embedding(default_plugin_resolver):
+    dpr = default_plugin_resolver
+    matrix = np.arange(6).reshape(2, 3)
+    node_map = dpr.wrappers.NodeMap.NumpyNodeMap(
+        np.array([0, 1]), nodes=np.array([9990, 9991])
+    )
+
+    MultiVerify(dpr).compute(
+        "embedding.apply.nodes", matrix, node_map, np.array([9990])
+    ).assert_equal(np.array([[0, 1, 2]]))
+    MultiVerify(dpr).compute(
+        "embedding.apply.nodes", matrix, node_map, np.array([9991])
+    ).assert_equal(np.array([[3, 4, 5]]))
+    MultiVerify(dpr).compute(
+        "embedding.apply.nodes", matrix, node_map, np.array([9990, 9991])
+    ).assert_equal(matrix)
+    MultiVerify(dpr).compute(
+        "embedding.apply.nodes", matrix, node_map, np.array([9991, 9990])
+    ).assert_equal(np.array([[3, 4, 5], [0, 1, 2]]))
