@@ -33,21 +33,21 @@ def test_nodemap_sort(default_plugin_resolver):
     dpr = default_plugin_resolver
     py_node_map = {index: index * 100 for index in range(1, 8)}
     mv = MultiVerify(dpr)
-    mv.compute("util.nodemap.sort", py_node_map).assert_equal(
-        np.array([1, 2, 3, 4, 5, 6, 7])
-    )
-    mv.compute("util.nodemap.sort", py_node_map, True, 4).assert_equal(
-        np.array([1, 2, 3, 4])
-    )
-    mv.compute("util.nodemap.sort", py_node_map, True).assert_equal(
-        np.array([1, 2, 3, 4, 5, 6, 7])
-    )
-    mv.compute("util.nodemap.sort", py_node_map, False, 3).assert_equal(
-        np.array([7, 6, 5])
-    )
-    mv.compute("util.nodemap.sort", py_node_map, False).assert_equal(
-        np.array([7, 6, 5, 4, 3, 2, 1])
-    )
+    mv.compute("util.nodemap.sort", py_node_map).normalize(
+        dpr.types.Vector.NumpyVectorType
+    ).assert_equal(np.array([1, 2, 3, 4, 5, 6, 7]))
+    mv.compute("util.nodemap.sort", py_node_map, True, 4).normalize(
+        dpr.types.Vector.NumpyVectorType
+    ).assert_equal(np.array([1, 2, 3, 4]))
+    mv.compute("util.nodemap.sort", py_node_map, True).normalize(
+        dpr.types.Vector.NumpyVectorType
+    ).assert_equal(np.array([1, 2, 3, 4, 5, 6, 7]))
+    mv.compute("util.nodemap.sort", py_node_map, False, 3).normalize(
+        dpr.types.Vector.NumpyVectorType
+    ).assert_equal(np.array([7, 6, 5]))
+    mv.compute("util.nodemap.sort", py_node_map, False).normalize(
+        dpr.types.Vector.NumpyVectorType
+    ).assert_equal(np.array([7, 6, 5, 4, 3, 2, 1]))
 
 
 def test_nodemap_select(default_plugin_resolver):
@@ -465,27 +465,6 @@ def test_edgemap_from_edgeset(default_plugin_resolver):
     )
 
 
-def test_node_embedding_apply(default_plugin_resolver):
-    dpr = default_plugin_resolver
-    matrix = np.arange(6).reshape(2, 3)
-    node_map = dpr.wrappers.NodeMap.NumpyNodeMap(
-        np.array([0, 1]), nodes=np.array([9990, 9991])
-    )
-
-    MultiVerify(dpr).compute(
-        "util.node_embedding.apply", matrix, node_map, np.array([9990])
-    ).assert_equal(np.array([[0, 1, 2]]))
-    MultiVerify(dpr).compute(
-        "util.node_embedding.apply", matrix, node_map, np.array([9991])
-    ).assert_equal(np.array([[3, 4, 5]]))
-    MultiVerify(dpr).compute(
-        "util.node_embedding.apply", matrix, node_map, np.array([9990, 9991])
-    ).assert_equal(matrix)
-    MultiVerify(dpr).compute(
-        "util.node_embedding.apply", matrix, node_map, np.array([9991, 9990])
-    ).assert_equal(np.array([[3, 4, 5], [0, 1, 2]]))
-
-
 def test_isomorphic(default_plugin_resolver):
     dpr = default_plugin_resolver
     #   0 1 2 3 4            0 1 2 3 4
